# frozen_string_literal: true

require 'distributed_press'

Jekyll::Hooks.register :site, :post_write, priority: :low do |site|
  next unless ENV['JEKYLL_ENV'] == 'production'

  hostname   = ENV['DISTRIBUTED_PRESS_PROJECT_DOMAIN']
  hostname ||= site.config['hostname']
  hostname ||= URI(site.config['url']).hostname

  raise URI::Error unless hostname

  distributed_press = DistributedPress.new project_domain: hostname
  distributed_press.configure && distributed_press.publish(site.dest)
rescue URI::Error
  Jekyll::Logger.warn "`hostname` or `url` keys missing on _config.yml, skipping Distributed Press publication."
end
